<?php

/**
 * Adds Awaken_Carousel_Posts widget.
 */
class Awaken_Carousel_Posts extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'awaken_pro_carousel', // Base ID
			__( 'Awaken: Carousel Posts', 'awaken-pro' ), // Name
			array( 'description' => __( 'Displays posts in a carousel.', 'awaken-pro' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Latest Posts', 'awaken-pro' );	
		$category = ( ! empty( $instance['category'] ) ) ? $instance['category'] : '';
		$number_posts = ( ! empty( $instance['number_posts'] ) ) ? absint( $instance['number_posts'] )  : 9; 
		$sticky_posts = ( isset( $instance['sticky_posts'] ) ) ? $instance['sticky_posts'] : false;

		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
		?>

		<div class="owl-carousel awp-carousel">

		<?php

		$the_query = new WP_Query( array (
				'post_type'				=> 'post',
				'cat' 					=> $category,
				'posts_per_page' 		=> $number_posts,
				'ignore_sticky_posts' 	=> $sticky_posts
			)
		);

		if ( $the_query->have_posts() ) :
			while( $the_query->have_posts() ) : $the_query->the_post();
				echo '<div class="awp-carousel-post">';
					echo '<div class="awp-carousel-figure">';
					if ( has_post_thumbnail() ) :
						the_post_thumbnail('featured');
					else :
						echo '<img src="' . get_template_directory_uri() . '/images/carousel.png">';
					endif;
					echo '</div>';
					echo '<a href="'. esc_url( get_permalink() ) .'" rel="bookmark">';
						echo '<div class="awp-carousel-content">';
							the_title( '<h3 class="awp-carousel-title">', '</h3>' );
						echo '</div>';
					echo '</a>';
				echo '</div>';
			endwhile;
		endif;

		?>

		</div>

	<?php
		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$defaults = array(
			'title'		=>	__( 'Latest Posts', 'awaken-pro' ),
			'category'	=>	'all',
			'number_posts'	=> 9,
			'sticky_posts' => true,
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
		$number_posts   = isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] ) : 3;

		$title = ! empty( $instance['title'] ) ? $instance['title'] : __( 'Latest Posts', 'awaken-pro' );
		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( esc_attr( 'Title:' ) ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
			<label><?php _e( 'Select a post category', 'awaken-pro' ); ?></label>
			<?php wp_dropdown_categories( array( 'name' => $this->get_field_name('category'), 'selected' => $instance['category'], 'show_option_all' => 'Show all posts' ) ); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'number_posts' ); ?>"><?php _e( 'Number of posts:', 'awaken-pro' ); ?></label>
			<input type="text" id="<?php echo $this->get_field_id( 'number_posts' ); ?>" name="<?php echo $this->get_field_name( 'number_posts' );?>" value="<?php echo $number_posts; ?>" size="3"/> 
		</p>
		<p>
			<input type="checkbox" <?php checked( $instance['sticky_posts'], true ) ?> class="checkbox" id="<?php echo $this->get_field_id('sticky_posts'); ?>" name="<?php echo $this->get_field_name('sticky_posts'); ?>" />
			<label for="<?php echo $this->get_field_id('sticky_posts'); ?>"><?php _e( 'Hide sticky posts.', 'awaken-pro' ); ?></label>
		</p>		
		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );	
		$instance[ 'category' ]	= $new_instance[ 'category' ];
		$instance[ 'number_posts' ] = (int)$new_instance[ 'number_posts' ];
		$instance[ 'sticky_posts' ] = (bool)$new_instance[ 'sticky_posts' ];
		return $instance;
	}


} // class Awaken_Carousel_Posts

// register Awaken_Carousel_Posts widget
function register_awaken_carousel_posts() {
    register_widget( 'Awaken_Carousel_Posts' );
}
add_action( 'widgets_init', 'register_awaken_carousel_posts' );